@@ -54,7 +54,7 @@ else:
 del encoding
 
 # global variable: version
-version = "0.9.0"
+version = "0.9.1"
 
 # global variable: dpy
 dpy = None
@@ -352,6 +352,12 @@ class OptionLine:
         if type == "bool":
             self.widget = gtk.ToggleButton ()
             self.widget.set_use_stock (True)
+            # Make sure the button doesn't change size when toggled
+            self.widget.set_label ("gtk-yes")
+            wYes = self.widget.size_request()[0]
+            self.widget.set_label ("gtk-no")
+            wNo = self.widget.size_request()[0]
+            self.widget.set_size_request (max(wYes, wNo), -1)
             if value:
                 self.widget.set_label ("gtk-yes")
             else:
@@ -716,7 +722,7 @@ if gtk.__dict__.has_key("AboutDialog"):
                 translators = None
             self.set_name("DRIconf")
             self.set_version(version)
-            self.set_copyright(u"Copyright \u00a9 2003-2005  "
+            self.set_copyright(u"Copyright \u00a9 2003-2006  "
                                u"Felix K\u00fchling")
             self.set_comments(_("A configuration applet for DRI drivers"))
             self.set_website(u"http://dri.freedesktop.org/wiki/DriConf")
